@@ -24,7 +24,7 @@
 #include <ntqlayout.h>
 #include <ntqtooltip.h>
 #include <ntqdict.h>
-#include <ntqlist.h>
+#include <ntqptrlist.h>
 #include <ntqwhatsthis.h>
 #include <ntqstylesheet.h>
 
@@ -201,7 +201,7 @@ const KBiffURL KBiffSetup::getCurrentMailbox() const
   return mailboxTab->getMailbox();
 }
 
-const TQList<KBiffMailbox> KBiffSetup::getMailboxList() const
+const TQPtrList<KBiffMailbox> KBiffSetup::getMailboxList() const
 {
   return mailboxTab->getMailboxList();
 }
@@ -1643,9 +1643,9 @@ const KBiffURL KBiffMailboxTab::getMailbox() const
     return url;
 }
 
-const TQList<KBiffMailbox> KBiffMailboxTab::getMailboxList() const
+const TQPtrList<KBiffMailbox> KBiffMailboxTab::getMailboxList() const
 {
-    TQList<KBiffMailbox> mbox_list;
+    TQPtrList<KBiffMailbox> mbox_list;
 
     for (TQListViewItem *item = mailboxes->firstChild();
          item;
@@ -1932,7 +1932,7 @@ KBiffAboutTab::KBiffAboutTab(TQWidget *parent_)
   pixmap_label->setPixmap(logo_pixmap);
 
   // we want a bigger logo
-  TQFont logo_font = TQFont::defaultFont();
+  TQFont logo_font = TQApplication::font();
   logo_font.setPointSize(logo_font.pointSize() * 1.5);
   logo_font.setBold(true);
 
